@@ -50,7 +50,7 @@ use base qw(CipUX);
     #   - xmlrpc
     #   - extract_data_for_tpl
 
-    use version; our $VERSION = qv('3.4.0.6');
+    use version; our $VERSION = qv('3.4.0.7');
     use re 'taint';    # Keep data captured by parens tainted
     delete @ENV{qw(PATH IFS CDPATH ENV BASH_ENV)};    # Make %ENV safer
 
@@ -90,11 +90,11 @@ use base qw(CipUX);
         # +------------------------------------------------------------------+
         # | main
 
-        # not needed, is already sub lcass
+        # not needed, is already sub class
         #$cipux         = CipUX->new();
 
         # TODO: make that cfg aware
-        Log::Log4perl::init_once('/etc/cipux-cat-web/log4perl.conf');
+        #Log::Log4perl::init_once('/etc/cipux-cat-web/log4perl.conf');
 
         # +------------------------------------------------------------------+
         # | API
@@ -814,7 +814,7 @@ CipUX::RPC::Client - XML-RPC client call library
 
 =head1 VERSION
 
-This document describes CipUX::RPC::Client version 3.4.0.6
+This document describes CipUX::RPC::Client version 3.4.0.7
 
 
 =head1 SYNOPSIS
